@@ -21,6 +21,14 @@ class IsEndState(Criteria):
         return state.reach_right_end()
 
 
+class CandidateHasSymbols(Criteria):
+    def __init__(self, symbols: dict):
+        super(CandidateHasSymbols, self).__init__('CandidateHasSymbols', symbols)
+
+    def accept(self, state: EnSequence) -> bool:
+        return state.have_symbol
+
+
 class IsEndSymbolZH(Criteria):
     def __init__(self, symbols: dict, white_list: str = data):
         super(IsEndSymbolZH, self).__init__('IsEndSymbolEN', symbols)
@@ -563,7 +571,7 @@ class NotInWhitelistDotEn(SpecialCondition):
                             # state.v_pointer = state.v_pointer + i + word_len - dots_pos
                             return False
                         dots_pos = self.find_dot(word_token, dots_pos + 1)
-                        atcual_word = ''.join(state[index - dots_pos:index+1])
+                        atcual_word = ''.join(state[index - dots_pos:index + 1])
             return True
 
     def find_dot(self, str_list: List[str], start=0):
