@@ -112,8 +112,8 @@ class LongHandlerEN(Operation):
         self.is_next_with_space = condition.IsNextWithSpace(symbols)
 
         self.min_sentence_length = min_sentence_length
-        self.is_dialogue_gt = condition.DialogueIsGreaterThanEN(min_sentence_length)
-        self.is_bracket_gt = condition.BracketIsGreaterThan(min_sentence_length, symbols)
+        self.is_dialogue_gt = condition.DialogueIsGreaterThanEN(3)
+        self.is_bracket_gt = condition.BracketIsGreaterThan(3, symbols)
         self.space = self.symbols['all_symbols']
         self.blank = re.compile('^\s+$')
         self.is_right_quota = condition.IsRightQuotaEn()
@@ -301,7 +301,8 @@ class LongHandlerEN(Operation):
                 return i, True
 
             elif self.symbols['bracket_right'].match(
-                    state.current_value) and sub_len > self.min_sentence_length and self.is_bracket_gt(state):
+                    state.current_value) and sub_len > self.min_sentence_length and self.is_bracket_gt(
+                state) and self.is_next_with_space(state):
                 return min(i, state.length - 1), True
 
             elif self.is_s_quota_right(state) and state.pre_value[
