@@ -139,6 +139,7 @@ class StrSequence:
 class EnSequence(StrSequence):
     def __init__(self, str_block: str, verbose=None, symbols=SYMBOLS_EN):
         super().__init__(str_block, verbose, symbols)
+        self.en_symbols = re.compile('[a-zA-Z0-9]')
         self.value = self.tokenize(str_block)
         self.length = len(self.value)
         self.__candidate_len = 0
@@ -146,6 +147,8 @@ class EnSequence(StrSequence):
         self.s_quota_left = 0
         self.is_blank = re.compile('^\s+')
 
+        self.have_symbol = False
+
     def tokenize(self, str_block: str):
         pattern: re.Pattern = self.symbols['all_symbols']
         return [v for v in pattern.split(str_block) if v]
@@ -157,7 +160,7 @@ class EnSequence(StrSequence):
             elif self.v_pointer == self.length - 1:
                 return True
             elif self.is_blank.match(self.pre_value) or self.is_blank.match(self.next_value):
-                if self.pre_value not in ['s','n']:
+                if self.pre_value not in ['s', 'n']:
                     return True
             else:
                 return False
@@ -193,11 +196,13 @@ class EnSequence(StrSequence):
         self.v_pointer = min(self.v_pointer + 1, self.length - 1)
         if not self.symbols['all_symbols'].match(self.current_value):
             self.__candidate_len += 1
-
+        if ''.join(SYMBOLS_EN['all_symbols'].findall(self.current_value)).strip():
+            self.have_symbol = True
         # -- update pointer -- #
         self.update_barcket()
         self.update_quota()
         self.update_bookmark()
+
         if self.verbose:
             print_percent(self.v_pointer, self.length, 'process cutting')
 
@@ -205,3 +210,4 @@ class EnSequence(StrSequence):
         self.sentence_list_idx.append((self.sentence_start, min(self.length, self.v_pointer + 1)))
         self.sentence_start = self.v_pointer + 1
         self.__candidate_len = 0
+        self.have_symbol = False
