@@ -88,7 +88,8 @@ class StateMachine:
                 if self.__run_condition(child, value):
                     vertex = child_node
                     if verbose:
-                        print(value)
+                        #print(value)
+                        print(value.v_pointer)
                         if vertex.name != pre_v:
                             print('<{}>:'.format(vertex.name))
                             pre_v = vertex.name
