@@ -20,6 +20,7 @@ def init_nodes(**kwargs):
     # --- initialize condition & operation --- #
     edges = attrdict.AttrDict({
         'is_end_symbol': condition.IsEndSymbolEN(SYMBOLS),
+        'data_has_symbol': condition.CandidateHasSymbols(SYMBOLS),
         'is_bracket_close': condition.IsBracketClose(SYMBOLS),
         'is_book_close': condition.IsBookClose(SYMBOLS),
         'is_quote_close': condition.IsQuoteClose(SYMBOLS),
@@ -48,7 +49,7 @@ def init_nodes(**kwargs):
         'init': operation.Indolent(SYMBOLS),
         'quota_handler': operation.Indolent(SYMBOLS, name='quota_handler'),
         'quota_single_handler': operation.Indolent(SYMBOLS, name='quota_single_handler'),
-        #'end': operation.EndState(SYMBOLS)
+        # 'end': operation.EndState(SYMBOLS)
     })
     nodes['end'] = operation.CleanNode(node_list=list(nodes.values()))
     return edges, nodes
@@ -88,7 +89,10 @@ def long_cuter_en(**kwargs):
                 'args': all,
                 'node': nodes.do_cut},
 
-            {'edge': edges.is_long_sentence,
+            {'edge': [edges.is_long_sentence,
+                      edges.data_has_symbol],
+
+             'args': all,
              'node': nodes.long_handler},
 
         ],
