@@ -395,8 +395,9 @@ class test_spliter(unittest.TestCase):
                   "heir of Korea's largest chaebol.",
                   " Ms. Lee is currently running the family's Shilla hotel chain.",
                   ' With everything from money to power, Lee Bo-jin has always been dubbed the '
-                  '"No. 1 Korean woman" and ranked 87th in the top 100 most powerful women in '
-                  'the world voted by Forbes magazine.',
+                  '"No. 1 Korean woman" ',
+                  'and ranked 87th in the top 100 most powerful women in the world voted by '
+                  'Forbes magazine.',
                   ' However, inside that flashy life is a tragic life of the "Samsung '
                   'princess".',
                   ' *\n    *Princess means the richest woman in the country.']
