@@ -210,10 +210,9 @@ I wept like a child. "Dear mountains! my own beautiful lake! how do you welcome
                   'Justice (AAJC) told CNN,',
                   ' “Unfortunately, Asian Americans and Pacific Islanders often are invisible '
                   'to the public.',
-                  ' Or, where we are visible, it falls into a couple of different stereotypes. '
-                  'One stereotype is the so called ‘model minority’',
-                  ' — the suggestion that there are no issues that really affect the Asian '
-                  'American community.” ']
+                  ' Or, where we are visible, it falls into a couple of different stereotypes.',
+                  ' One stereotype is the so called ‘model minority’ — the suggestion that '
+                  'there are no issues that really affect the Asian American community.” ']
         self.assertEqual(expect, acutal)
 
     # @unittest.skip('pass')
@@ -330,11 +329,12 @@ I wept like a child. "Dear mountains! my own beautiful lake! how do you welcome
         __long_machine_en.run(m_input)
         acutal = m_input.sentence_list()
         print(acutal)
-        expect = [
-            'Quidditch team: three Chasers, whose job it was to score goals by putting the Quaffle(a red, soccer-sized ball)',
-            ' through one of the fifity-foot-high hoops at each end of the field;',
-            'two Beaters, who were equipped with heavy bats to repel the Budgers(two heavy black balls that zoomed around trying to attack the players)',
-            '; a Keeper who defended the goalposts, and the Seeker, who had the']
+        expect = ['Quidditch team: three Chasers, whose job it was to score goals by putting '
+                  'the Quaffle(a red, soccer-sized ball)',
+                  ' through one of the fifity-foot-high hoops at each end of the field;',
+                  'two Beaters, who were equipped with heavy bats to repel the Budgers(two '
+                  'heavy black balls that zoomed around trying to attack the players);',
+                  ' a Keeper who defended the goalposts, and the Seeker, who had the']
         self.assertEqual(expect, acutal)
 
     def test_bug_2021_5_25_13(self):
@@ -348,11 +348,22 @@ I wept like a child. "Dear mountains! my own beautiful lake! how do you welcome
                   ' Lavernder Browb claooed her hands on']
         self.assertEqual(expect, acutal)
 
+    def test_bug_2021_5_25_13_1(self):
+        paragraph = '''the dog in the shadows of Magnolia Crescent. ? ! Lavernder Browb claooed her hands on'''
+        __long_machine_en = StateMachine(long_cuter_en(min_len=2, max_len=30))
+        m_input = EnSequence(paragraph)
+        __long_machine_en.run(m_input)
+        acutal = m_input.sentence_list()
+        print(acutal)
+        expect = ['the dog in the shadows of Magnolia Crescent. ? !',
+                  ' Lavernder Browb claooed her hands on']
+        self.assertEqual(expect, acutal)
+
     # 这个是一个分复杂的例子
     def test_bug_2021_5_25_14(self):
         paragraph = '''"Yeh always wait fer the hippogriff ter make the firs' move," Hagrid cointinued. "It's polite, see? Yeh walk toward him, and yeh bow, an' yeh wait. If he bows back, yeh're allowed ter toych him. If he desn' bow, then get away from him sharpish,' cause those talons hurt.'''
 
-        paragraph = "\"Yeh always wait fer the hippogriff ter make the firs' move,\" Hagrid cointinued. \"It's polite, see? Yeh walk toward him, and yeh bow, an' yeh wait. If he bows back, yeh're allowed ter toych him. If he desn' bow, then get away from him sharpish,' cause those talons hurt."
+        #paragraph = "\"Yeh always wait fer the hippogriff ter make the firs' move,\" Hagrid cointinued. \"It's polite, see? Yeh walk toward him, and yeh bow, an' yeh wait. If he bows back, yeh're allowed ter toych him. If he desn' bow, then get away from him sharpish,' cause those talons hurt."
 
         __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
         m_input = EnSequence(paragraph)
@@ -371,6 +382,6 @@ I wept like a child. "Dear mountains! my own beautiful lake! how do you welcome
         __long_machine_en.run(m_input)
         acutal = m_input.sentence_list()
         print(acutal)
-        expect = ['In the new economy, computer science isn\'t an optional skill – it\'s a basic skill, right along with the three "Dr."',
-                  " Steven Nine out of ten parents want it taught at their children's schools"]
-        self.assertEqual(expect, acutal)
\ No newline at end of file
+        expect = ["In the new economy, computer science isn't an optional skill – it's a basic skill,",
+                  ' right along with the three "Dr." Steven Nine out of ten parents want it taught at their children\'s schools']
+        self.assertEqual(expect, acutal)
